.. _developer:

=================================
Developing Additional RPC Support
=================================

:mod:`pyramid_rpc` is a community developed and support package. As such, the
developers primarily support the RPC methods they actually use. Contributors
are welcome to add support for their preferred RPC method.

Contributions should follow the `Pylons Project Community guidelines.
<http://docs.pylonsproject.org/#contributing>`_ and include appropriate unit
tests, with nosetest skip's for developers to run tests that don't have
dependent RPC packages installed.
